Coverage for /home/agp/Documents/me/code/brotation/brotation/__init__.py: 100%

# Coverage for /home/agp/Documents/me/code/brotation/brotation/__init__.py : 100%

## 3 statements 3 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1"""Top-level package for Backup-Rotation."""

2

3 __author__ = """Asterio Gonzalez"""

4 __email__ = 'asterio@protonmail.com'

5 __version__ = '0.1.0'